#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-4Uavk7LfYy87StM8o8xCNr
key:                  http-download-0.2.1.0-4Uavk7LfYy87StM8o8xCNr
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  7362e9b086a88d64c70b62129ee670fa
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-4Uavk7LfYy87StM8o8xCNr
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-746voJok0ldKgJVOvUeNqZ
    bytestring-0.11.5.3 conduit-1.3.6.1-2XNnm6ghB217IzkuUaD6MV
    conduit-extra-1.3.8-4ZSxTr4cq1zBTUmvY3qFnu
    crypton-1.0.4-TJn5R4YGxkHJI4uBMudyO
    crypton-conduit-0.2.3-5izcvxIdEjX7VHgTue5xsf directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    http-client-0.7.19-HpBpFDcF8eMLX9tct0xZ3w
    http-conduit-2.3.9.1-H1OZLvFnGrHFofiuk514H6
    http-types-0.12.4-E7NglevSDUe4aFzTHGY2t7
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    path-0.9.6-Jg4esW7GsX5HwUBdKQ7haV
    path-io-1.8.2-7wNzDgEUROALIGTJjUvVrF
    retry-0.9.3.1-6PbDolHQTOQ3QA6HUWrGba
    rio-0.1.24.0-Io2GrfE1HdG3vx42ymtTp2
    rio-prettyprint-0.1.8.0-ANixhWFG3QH105HLnDkGSP

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

